@@ -40,6 +40,7 @@ class HttpRequest(object):
         def fun_wrapper(*args, **kwargs):
             self.func_return = self.func(*args, **kwargs) or {}
             self.func_im_self = args[0] if self.is_class else object
+            self.fun_kwargs = kwargs
 
             try:
                 self.func.__doc__ = self.func.__doc__.decode('utf-8')
@@ -63,6 +64,7 @@ class HttpRequest(object):
         base_url = getattr(self.func_im_self, 'base_url', '')
         self.url = self.func_return.pop('url', None) or self.url
         self.url = urljoin(base_url, self.url)
+        self.url = self.url.format(**self.fun_kwargs)
 
     def create_session(self):
         """
